Handbook - Muscle System Introduction
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

MUSCLE SYSTEM INTRODUCTION Click pictures for new window with figure and legend, click again for high resolution image
1 Overview There are two main types of muscle in C. elegans: multiple sarcomere/obliquely striated (somatic) and nonstriated (also called single sarcomere). The multiple sarcomere muscles contain evenly distributed attachment points to the hypodermis and cuticle along their length (see Somatic muscle), whereas the majority of the nonstriated muscles have focal attachment points at their ends. The multiple sarcomere group is the most abundant muscle group, consisting of 95 body wall muscles; 14 of these are post-embryonically generated (see Somatic muscle). The nonstriated muscle group in hermaphrodites includes 20 pharyngeal muscles, 2 stomato-intestinal muscles, 1 anal sphincter muscle, 1 anal depressor muscle, 8 vulval muscles (all post-embryonically generated), 8 uterine muscles (all post-embryonically generated) and contractile gonadal sheath (see Nonstriated Muscle). In the male, instead of the vulval and uterine muscles and gonadal sheath, 41 specialized mating muscles are present, some having single sarcomeres and some being obliquely striated. Except for the pm1-pm5 cells of the pharynx, all muscle cells are mononucleate. After hatching, pm1 becomes a syncytial cell with 6 nuclei, and pm2-pm5 become binucleate syncytial cells (see Alimentary System - Pharynx). Although most muscle contractions are generated by nerve transmission, three rhythmic behavior cycles in C. elegans are dependent on periodical contraction of certain muscle groups with recurrent intracellular Ca++ transients rather than excitation by neuronal transmission. These are: pharyngeal pumping behavior of the pharyngeal muscle (see Alimentary system - Pharynx), gonadal sheath contractions, and the defecation cycle involving three muscle groups: body wall (somatic) muscles near the head, posterior (somatic) body wall muscles and enteric muscles (i.e., anal depressor, sphincter, and stomato-intestinal muscles) (see Alimentary system - Rectum and Anus). Although they are generated by intrinsic motor activity, pharyngeal pumping and enteric muscle contractions are modulated by neurons. 2 Structure of the Contractile Apparatus The basic unit of the contractile apparatus in muscle is the sarcomere (MusFIG1A). In striated muscle these contractile units are repeated, giving the muscle its "striated" appearance. In vertebrates, a sarcomere is comprised of Z (Zwischenscheibe) discs located at each end of sarcomere; I (isotropic) bands, which correspond to thin filaments; A (anisotropic) bands, which correspond to thick filaments (including the thin filament overlap region); H (Heller) bands, which correspond to the central region of the A bands and M lines at the middle of the H bands where each myosin rod is joined end-to-end with its myosin rod neighbor (MusFIG 1). In the sarcomere, myosin-containing thick filaments are interdigitated with actin-containing thin filaments on either side. In C. elegans, the Z-disc analog is the dense body (DB), which functions to anchor and align thin filaments in striated muscles (MusFIG 1B; see Somatic Muscle). Thick filaments are attached to M-line analogs. Both the DB and the M-line analogs extend the entire depth of the lattice and anchor all filaments to the cell membrane and the underlying hypodermis and cuticle (see Somatic Muscle). In nonstriated muscles with single sarcomeres, large hemiadherens junctions (formerly called hemidesmosomes) connect each sarcomere at the muscle ends to body cuticle or specialized cuticle and/or to basal lamina to anchor the myofilaments (see Nonstriated Muscle). Some of the nonstriated muscles have myofilaments that are less well organized. Here, anchorages occur via small plaques and hemiadherens junctions distributed along the cell membrane similar to the organization of vertebrate smooth muscle (MusFIG 1A&B and MusFIG 1C&D, see Nonstriated Muscle). The organization of the muscle filament lattice in C. elegans can be viewed by polarized light microscopy, to both assess the orientation of the filaments in wild type body muscles as they develop and to score for defects in mutant strains. MusFIG 1A & B: The contractile apparatus in C. elegans. A. Transmission electron microscopy (TEM) image of a cross section of the contractile apparatus in a body wall. The filaments of the lattice are oriented longitudinally and perpendicular to the surface. Dense bodies (DBs) anchor the thin (actin) filaments, whereas M line-homologs anchor the thick (myosin) filaments. A single unit of myofilament lattice between two DBs is called a sarcomere and contains one A band in the middle and two juxtaposing half I bands. In C. elegans, each adult body wall sarcomere is about 1 μm wide. Bar, 0.5 μm. (SR) Sarcoplasmic reticulum. (Image source: [Hall] N501C R4.) B. Diagram illustrating the contractile lattice and the placement and structure of the SR. The vesicular membranous network of SR surrounds the myofilament lattice and is present along dense bodies and the apical plasma membrane underneath the lattice (see left inset, A). (Green squares) Voltage gated Ca++ channels (EGL-19); (red oblongs) ryanodine receptors; (yellow dots) thick filaments; (black dots) thin filaments; (orange layer) basal lamina with extracellular matrix (gray filaments); (beige layer) hypodermis; (gray layer) cuticle.
MusFIG 1C & D: The contractile apparatus in vertebrates. C. Diagram illustrating vertebrate striated muscle. Vertebrate somatic muscle is comprised of numerous multinucleated myofibers, each of which contains many contractile myofibrils with repeating sarcomeres and develops by fusion of embryonic myoblasts. A single contractile unit between two Z discs in each myofibril is a sarcomere. In each sarcomere, myosin-containing thick filaments (thick brown bands) are interdigitated with actin-containing thin filaments (thin brown bands) on either side. Thin filaments are attached end to end at the Z lines, in the middle of the I-bands, and thick filaments are attached end to end at the M-lines, in the middle of the A-bands. Muscle contraction involves myosin sliding past actin to shorten the sarcomere. D. Diagram illustrating vertebrate smooth muscle. Vertebrate smooth muscle consists of unfused, spindle-shaped individual cells, each with a single nucleus. There is no apparent organization of the actin and myosin filaments into discrete contractile units.
3 Excitation-contraction Coupling 3.1 EC Coupling in Vertebrate Muscle Excitation-contraction coupling (ECC) is the process by which an action potential triggers a muscle cell to contract. In vertebrates, myocytes respond to the excitation signal induced by their innervating motor neurons with a rapid depolarization, which is coupled with contraction of the muscle as its physiological response. The initial depolarization in the muscle caused by nerve transmission is a localized phenomenon and the depolarization signal is carried to the myofibrils deep within the cell body via sarcolemmal (cell membrane) invaginations called transverse (T) - tubules. T-tubules form a network of membranes that penetrate and span the cross section of each muscle cell, transmitting the depolarization signal uniformly throughout the muscle fiber (MusFIG 2). The lumena of the T-tubules are continuous with the extracellular fluid, and the membrane depolarization during an action potential diffuses across the T-tubule membrane. The T-tubules are close to the border between the A- and I-bands of the myofibrils and are in close apposition with cisternae formed by the Sarcoplasmic Reticulum (SR). This association is called a triad. T-tubules are essential structures for excitation-contraction coupling linking the depolarization of the action potential to Ca++ release from SR where intracellular Ca++ is sequestered (MusFIG 2B). Depolarization in the T-tubule membrane leads to release of stored Ca++ through the interaction of two proteins. A voltage sensor (dihydropyridine receptor [DHPR] which is a voltage-gated Ca++ channel) in the T-tubule membrane changes conformation in response to the action potential (MusFIG 2A). This conformational change is transmitted to another Ca++ channel (Ryanodine receptor [RyR]) on SR, causing it to open and allowing Ca++ release from SR stores (Ahern et al., 2001). RyRs cluster in the junctions between SR and T-tubules. The direct mechanical interaction between DHPR and RyR is specific for excitation-contraction coupling in vertebrate skeletal muscle. Increased intracellular free calcium then binds to troponin-C (TN-C), part of the regulatory complex attached to the thin (actin) filaments of the sarcomere (Alberts et al., 2002). When Ca++ binds to the TN-C, a conformational change in the regulatory complex relieves the tropomyosin blockage of the interaction between actin and the myosin head. A myosin ATPase located on the myosin head supplies energy for the movement between the myosin heads and actin. The actin and myosin filaments slide past each other (ratcheting) and shorten the sarcomere length (Alberts et al., 2002). One ratcheting cycle will last as long as the cytosolic Ca++ remains elevated. At the end of contraction, Ca++ is restored to sarcoplasmic reticulum by an ATP-dependent calcium pump. MusFIG 2: Schematic showing T-tubule structure in vertebrate muscle. A. Illustration of T-tubules spanning a muscle cell. B. Diagram shows close apposition of the T-tubules with cisternae formed by the sarcoplasmic reticulum. The lumena of the T-tubules are continuous with the extracellular fluid and the membrane depolarization during an action potential diffuses across the T-tubule membrane. 3.2 EC Coupling in C. elegans Muscle In C. elegans, sarcoplasmic reticulum (SR) consists of a network of vesicular membranous organelles surrounding the myofilament lattice. The flattened vesicles of SR extend around dense bodies (DBs) and lay adjacent to the apical (hypodermal side) plasma membrane underneath the lattice, where they are localized randomly between DBs (Waterston, 1988) (MusFIG 1) (see Somatic Muscle). A gap of 12-14 nm separates the SR vesicles from the plasma membrane. No equivalent to the T-tubule system exists in C. elegans, possibly because the direct apposition of SR to the plasma membrane abrogates its utility (MusFIG 1A&B) (Waterston, 1988). In C. elegans, the ryanodine receptor (RYR) is encoded by the unc-68 gene (Maryon et al., 1996; Hamada et al., 2002). Its expression is seen in various muscles including body wall muscles, terminal bulb muscle of the pharynx, vulval and uterine muscles, diagonal muscles of male tail, and the anal sphincter and depressor muscles (Maryon et al., 1998). In somatic muscle, initiation ofunc-68 expression coincides with the first twitching movements of the embryo. Within the body wall muscle, UNC-68 is thought to be localized to SR vesicles, primarily between the rows of dense bodies in the A-band region (Maryon et al., 1998). In contrast to vertebrate muscle, UNC-68 functions to enhance motility but it is not essential for excitation-contraction (E-C) coupling in C. elegans because unc-68 null mutants are still able to propagate coordinated contraction waves, albeit weakly. Following excitatory (cholinergic) neurotransmission at the NMJs of C. elegans, opening of nicotinic AChR (ligand-gated ion channels) on muscle membrane is thought to initiate graded action potentials in muscle arms which then converge and propagate to the contractile compartment of the muscle (Richmond and Jorgensen, 1999; Jospin et al., 2002; Schafer, 2002). There are no voltage-activated Na+ channels in C. elegans and the graded action potentials are thought to be dependent on voltage-activated Ca++ currents across the muscle plasma membrane through L-type channels. It is postulated that activation of these Ca++ channels (similar to dihydropyridine receptor [DHPR] and encoded by the egl-19 gene) on the plasma membrane provides sufficient Ca++ influx from extracellular space to directly initiate a contraction in the nematode body wall muscle where the sarcomeres are placed in close proximity to the plasma membrane (Lee et al., 1997; Maryon et al., 1998; Jospin et al., 2002). 4 Muscle Arms Unlike other organisms where neurons send processes to their target muscle cells to make synapses, neuromuscular junctions (NMJs) of C. elegans are made by arms grown from muscle cells toward motor neurons (MusFIG 3) (Stretton, 1976; Sulston and Horvitz, 1977; Sulston et al., 1983; White et al., 1986; Dixon and Roy, 2005; Dixon et al., 2006). Muscle arms have simple structures made of a stalk and a bifurcated terminus that contacts the neuron. Similar to chemical synapses between neurons, NMJs are made en passant by the innervating neurons onto these muscle arms (White et al., 1986). In a process bundle, each motor neuron process sporadically moves to the outside of the bundle to become accessible to muscle arms in synaptic regions. MusFIG 3: Muscle arms. A. Diagram of cross section of the body indicating muscle arms of the body wall muscles. In C. elegans, body wall muscles are arranged in four quadrants with two rows of muscle cells in each quadrant (only right side is labeled). Each body muscle cell is innervated by extending several muscle arms that reach the nearest nerve cord. No muscle arms are extended to the opposite cord. (Light orange line) Basal lamina separates the muscle from the nerve cords and the hypodermis. Hypodermis, which is stylized in this diagram for illustration purposes, separates muscle from cuticle. B. Schematic of the enteric muscles, lateral view. (Asterixes) Muscle arms from the enteric muscles synapsing onto DVB neuron.
4.1 Somatic Muscle Arms Among the 95 bodywall muscle (BWmu) cells, 16 head muscles have arms that synapse exclusively with the motor neurons of the nerve ring. Sixteen neck muscles have arms that extend both to the nerve ring and to the nearest nerve cord. The remaining 63 body muscles extend arms exclusively to the nearest nerve cord. Muscle arm development is highly stereotypical. Each body wall muscle in the body usually begins by growing a single muscle arm during embryonic development (MusFIG 4). At hatching, muscle cells have on average 1.7 (+/- 0.8) arms per cell (Dixon and Roy, 2005; Dixon et al., 2006). The number of arms increases to three or more by the adult stage, with young adults averaging 4.0 (+/- 1.0) arms per cell (Hall and Hedgecock, 1991; Dixon and Roy, 2005). Individual muscle cells are observed to contain a stereotypical number of arms, and the muscles lying in rows closest to the dorsal and ventral nerve cords (ventral right and dorsal left quadrants) have significantly more arms than their contralateral homologs. In adult body muscles, individual muscle arms vary in size, shape and branchiness where they contact the longitudinal nerve cords. Viewed in thin sections, the nerve cords are covered by a muscle plate over much of their length, but there are bare patches where no arms contact the nerve cords. The majority of post-embryonic muscle arm outgrowth is coincidental with and dependent on the birth of 53 extra motor neurons and occurs during late-L1 to early-L2 stage (Dixon and Roy, 2005). MusFIG 4: Muscle arm development. A-B. Head and neck muscle arm development. (Light green) primordial pharynx cells; (dark green) myoblasts; (red) nascent nerve ring; (orange) basal lamina; (beige) hypodermis. A. At about 350 min after first cell cleavage, head and neck muscles directly surround the pharynx primordium where the nerve ring will form. Shortly after, concurrent with amphid axon outgrowth (not shown), muscle cells are thought to migrate to the periphery, towards the hypodermis. B. As muscle cells migrate, they may leave attachments behind next to the pharynx, which later become the muscle arms. These muscle arms may then be guided towards their muscle plate positions around the nerve ring by the GLR cells (not shown). C-D. Body wall muscle development. It is suggested that muscle arm development from body wall muscles occurs in 2 phases: embryonic and larval. C. Muscle arms in the L2-stage larva. During mid embryogenesis myoblasts either move away or become displaced from motor neurons (not shown). As they move, they are thought to leave an arm behind, attached to the neurons. As a result, in newly hatched larva each muscle cell contains one to two muscle arms (dark green arms). Concomitant with post-embryonic motor neuron growth, additional larval muscle arms (light green arms) grow from these muscle cells towards the motor neurons (red) by active outgrowth (white arrow). D. In the adult, each muscle cell contains three to six arms. There are two suggested mechanisms of muscle arm development. First, during embryogenesis one-two arms are generated passively by migration of myoblasts away from their initial position next to the neurons (MusFIG 4) (Dixon et al., 2006). As myoblasts migrate to their final positions, their cell membranes stay in contact with a motor neuron process, thus generating muscle processes that stretch behind the migrating soma. In contrast, muscle arm growth during larval stages is thought to be an active extension process involving the actin cytoskeleton, extracellular matrix and guidance by chemoattraction (Dixon et al., 2006). Although the specific guidance cue for muscle arm extension is not yet known, the involvement of a guidance cue is supported by two lines of evidence. First, in a kinesin-defective (unc-104) mutant, in which anterograde transport of vesicles is disrupted, some of the dorsal body wall muscle arms extend towards the ventral cord, where dense core vesicles accumulate within motor neuron cell bodies (Hall and Hedgecock, 1991). In this mutant, it is suggested that the release of the muscle attractant occurs close to the neuron cell body where the vesicles are sequestered. Second, in unc-6 or unc-5 mutants, in which formation of motor neuron process bundles is erratic, body wall muscle arms extend to the lateral regions where the errant motor neuron processes are located (Hedgecock et al., 1990). Development of muscle arms from the head and neck muscles to the nerve ring (NR) may occur principally by the passive extension mechanism. Early in embryogenesis, head and neck muscle cells directly surround the pharynx. It is suggested that when these muscle cells later migrate towards the periphery, as the first amphid axons extend to initiate the formation of the nerve ring, they leave an arm behind, next to the pharynx (MusFIG 4) (C. Norris, pers. comm.). The arms left behind from neck muscles, which are located posterior to the GLR cells, are then thought to grow anteriorly to reach the nascent nerve ring actively. The head and neck muscle arms together define a fairly precise topological map (both circumferential and antero-posterior) of motor neurons and their target muscles along the inner surface of the nerve ring (MusFIG 5A&B, MusFIG 5C-F, MusFIG 5G and MusMOVIE 1) (White et al., 1986). GLR cells are suggested to function as mesodermal scaffolding cells that guide the muscle arms to their appropriate territories for development of this motor map (see Somatic Muscle and GLR Cells). In the adult, the motor neuron axons that innervate the head and neck muscles are located in the innermost regions of the nerve ring except those of RIML/R motor neurons, which run more laterally within the nerve ring. The head muscle arms, which receive innervation from RIML/R, hence make small branches, which may penetrate the basal lamina in four places to contact RIML/R axons (MusFIG 5A). MusFIG 5A & B: Muscle arms of the head muscles. A. Diagram showing two stylized head muscle arms (dark green) approaching nerve ring. Muscle arms from the 32 muscles in the head and neck project onto the inside surface of the nerve ring in a highly ordered fashion. Their terminal branches lie between the processes of GLR cells (golden yellow) on the inside and the motor neurons of the nerve ring (dark red and purple) on the outside. Arms from the somatic head muscles run posteriorly until they reach the posterior nerve ring region. The arms from each muscle row then make an anterior arc of about 45° and extend inward to reach between the outside surface of the GLRs and the inner surface of the neural plate. This inward turn involves close apposition to the GLR cell bodies (see GlrFIG 3). In the neck, somatic muscles extend arms both to the nerve ring and to either the ventral or dorsal nerve cords where they receive additional synapses (not shown). (Light green) pharynx; (orange) basal lamina. B. Graphic rendition of the structure of the nerve ring and interior muscle plate. The muscle arms (dark green) innervated by RIML/R (purple) make four small spurs that may pierce through the basal lamina to access these neurons. Other motor neuron processes (only RME neurons are indicated) are located adjacent to the inner surface of the nerve ring, where they make NMJs with the muscle arms. Only a few cells on the right side are labeled. (Based on White et al., 1986.) MusFIG 5C-F: Muscle arms of the head muscles. C-D. Head muscles and muscle arms. Epifluorescent images from a transgenic animal expressing the W05E10.4::GFP reporter gene. C. Left lateral view. D. Left lateral oblique view. The cylindrical muscle plate lying under the nerve ring is clearly seen. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) E- F. Anteriormost head muscles, ventral views. Epifluorescent images from a transgenic animal in which GFP is concentrated in nonsarcomeric portions of the muscle cell. E. The muscle arm from a muscle cell in the anterior ventral left quadrant is seen reaching the posterior of the nerve ring region, where it makes a turn to reach inside the nerve ring. F. The same animal, with the nerve ring region is shown in higher magnification. The ventral and lateral GLR cell bodies and the nerve ring are pseudocolored over the epifluorescent image to show their positions relative to the muscle arms and muscle plate. Muscle arms are thought to be guided by the GLR cell bodies to their correct positions along the nerve ring. Original magnification, 600x. (Strain source: M. Land and C. Rubin.) See also MusMOVIE1, a 3-D reconstruction of head muscles and muscle arms created by R. Newbury & Moerman lab using Zeiss LSM 5 Pascal software v. 3.2 from confocal images of a strain expressing the GFP marker linked to the promoter for W05E10.4. MusFIG 5G: Color-coded TEM of muscle arms from posterior head muscles. Posterior head muscles reach the muscle plate at the level shown (insert). The arms turn inward near the GLRDR cell body (only the anterior edge of the soma is seen) and their terminal branches insinuate between the CEPsh and neuron processes to reach between the neuron layer and the inner GLR process layer. The muscle plate is separated from the neurons by a basal lamina (not shown). Only the right side structures are labeled. Bar, 1 μm. (Image source: N2U [MRC] A190-17.) MusMOVIE 1: 3-D reconstruction of head muscles and muscle arms. 3-D movie was created from confocal images of a strain expressing the GFP marker linked to the promoter for W05E10.4 using Zeiss LSM 5 Pascal software v. 3.2. (Image source: R. Newbury and D. Moerman.) Click on image to play movie. In somatic muscle, the distal portions of muscle arms interdigitate abundantly in regions of neuromuscular junctions (MusFIG 6A-F, MusFIG 6G-K and MusMOVIE 2). The interdigitated muscle arms also make gap junctions to one another that are suggested to have a role in synchronous contractions of body muscles during embryonic elongation as well as in synchronizing the activity of left and right quadrants during normal body motion (Hall and Hedgecock, 1991) (see also Gap Junctions). MusFIG 6A-F: Muscle arms of the body wall muscles. A. Transverse-section TEM from the posterior head region. A muscle arm from the left-side neck muscles is seen crossing over the ventral hypodermal ridge and the ventral nerve cord (red lines) to receive innervation at the right edge of the major fascicle of the ventral nerve cord. Bar, 1 μm. (Image source: N2U [MRC] 240-18.) B- D. Epifluorescent micrographs from adult transgenic animals co-expressing the him-4p::MB::YFP (muscle), hmr-1b:: DsRed2 (neuron) and unc-129nsp:: DsRed2 (neuron) reporter genes. All are lateral views of the body. Each muscle cell extends 3-6 muscle arms (asterisks in D), mainly from the middle region of each cell. Upon reaching the nerve cord (inset inD, arrow) the muscle arm often bifurcates (inset in D arrowheads) and spreads along the basal lamina to interdigitate and receive input from cord motor neurons. (Strain source: P. Roy.) E- F. Epifluorescent micrographs from adult transgenic animals expressing the ZK822.5::GFP reporter. E. Lateral view shows slender muscle arms (arrowheads) reaching the ventral nerve cord. F. Ventral view, posterior body. Muscle arms extend from the each of the ventral muscle quadrants (only the right side is labeled) to the ventral nerve cord. The muscle cells that lie in outer rows extend their arms over their partners in the quadrant (arrowheads). (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].)
MusFIG 6G-K: Interdigitation of muscle arms from the dorsal neck muscles at the level of the dorsal cord. Illustrations are reconstructions made from tracings of serial section TEMs of neck muscles (based on [MRC] N2U series) (Liu et al., 2007). G. Image is representative of the micrographs used in the tracings. Transverse section from the dorsal side of the neck. (Red, yellow, green, blue, turquoise, and gray) Muscles and muscle arms; (red line) dorsal nerve cord. Some of these muscle arms may belong to the same (right side or left side) muscle cells, although they are shown in different colors here. The colors correspond to the muscles and muscle arms shown in subsequent (H-K) panels. Bar, 1 μm. (Image source: N2U A334-12) H. Transverse view. Cuticle is artistically rendered and is not from actual tracing. Muscle arms crowd around the dorsal nerve cord. I. Ventral view showing the extensive interdigitation of the muscle arms. J. Dorsal view. Shown are cell bodies of the two muscle cells (red and green) from the inner rows of the two dorsal muscle quadrants, which flank the dorsal cord. K. Dorsal view. Muscle cells are removed to expose the relationship between the dorsal cord and four muscle arms (gray, yellow, blue, and turquoise). (Lavender, pink, brown, and dark green) Reconstructions of four selected dorsal nerve cord neurons. The remaining dorsal cord neurons did not contact muscle arms at this level and, hence, were not traced. See MusMOVIE 2 for a 3-D reconstruction of how neck muscle arms interdigitate at the region of the dorsal nerve cord. MusMOVIE 2: Interdigitation of neck muscle arms. Illustrations are reconstructions made from tracings of serial section TEMs (by Tylon Stephney) of neck muscles (based on [MRC] N2U series) (Liu et al., 2007). Reconstruction was created by Huawei Weng using Imaris software. Click on image to play movie. 4.2 Nonstriated Muscle Arms Pharyngeal muscles do not extend muscle arms. No epithelial cells separate pharyngeal muscle from the pharyngeal nerves, placing many motor neurons in direct apposition to their target muscles for synaptic innervation. Some nerve bundles, such as M2 neurons, actually pass inside the muscles and make neuromuscular junctions to pharyngeal muscles inside the muscle cells (see Alimentary system - Pharynx). Among sex-specific hermaphrodite muscles, the only obvious muscle arms are made by vm1R muscles. These extend arms to the ventral cord to receive synaptic input from the ventral cord motor neurons VA7, VB6, and VD7 (see Reproductive system - Egg-laying Apparatus ) (White et al., 1986). The muscle arms from the anal depressor muscle, anal sphincter muscle and two stomatointestinal cells are quite long. All arms must extend to the preanal ganglion where they receive synapses from the DVB neuron (see Nonstriated Muscle). 5 References Ahern, C.A., Bhattacharya, D., Mortenson, L. and Coronado, R. 2001. A component of excitation-contraction coupling triggered in the absence of the T671-L690 and L720-Q765 regions of the II-III loop of the dihydropyridine receptor alpha(1s) pore subunit. Biophys. J. 81: 3294-307. Article Alberts, B., Johnson, A., Lewis, J., Raff, M., Roberts, K. and Walter, P. 2002. In "Molecular Biology of the Cell" Garland Science, New York. Book Dixon, S.J., Alexander, M., Fernandes, R., Ricker, N. and Roy, P.J. 2006. FGF negatively regulates muscle membrane extension in Caenorhabditis elegans. Development 133: 1263-1275. Article Dixon, S.J. and Roy, P.J. 2005. Muscle arm development in Caenorhabditis elegans. Development 132: 3079-3092. Article Hall, D.H. and Hedgecock, E.M. 1991. Kinesin-related gene unc-104 is required for axonal transport of synaptic vesicles in C. elegans. Cell 65: 837-847. Abstract Hamada, T., Sakube, Y., Ahnn, J., Kim, D.H. and Kagawa, H. 2002. Molecular dissection, tissue localization and Ca2+ binding of the ryanodine receptor of Caenorhabditis elegans. J. Mol. Biol. 324: 123-135. Abstract Hedgecock, E.M., Culotti, J.G. and Hall, D.H. 1990. The unc-5, unc-6, and unc-40 genes guide circumferential migrations of pioneer axons and mesodermal cells on the epidermis in C. elegans. Neuron 4: 61-85. Abstract Jospin, M., Jacquemond, V., Mariol, M.C., Segalat, L., Allard, B. 2002. The L-type voltage-dependent Ca2+ channel EGL-19 controls body wall muscle function in Caenorhabditis elegans. J. Cell Biol. 159: 337-347. Article Lee, R.Y.N., Lobel, L., Hengartner, M., Horvitz, H.R. and Avery, L. 1997. Mutations in the alpha1 subunit of an L-type voltage-activated Ca2+ channel cause myotonia in Caenorhabditis elegans. EMBO J. 16: 6066-6076. Article Liu, Q., Chen, B., Hall, D.H. and Wan,g Z-W. 2007. A quantum of neurotransmitter causes minis in multiple postsynaptic cells at the Caenorhabditis elegans neuromuscular junction. Dev. Neurobiol. 67: 123-128. Abstract Maryon, E.B., Coronado, R. and Anderson, P. 1996. unc-68 encodes a ryanodine receptor involved in regulating C. elegans body-wall muscle contraction. J. Cell Biol. 134: 885-893. Article Maryon, E.B., Saari, B. and Anderson, P. 1998. Muscle-specific functions of ryanodine receptor channels in Caenorhabditis elegans. J. Cell Sci. 111: 2885-2895. Article McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynski, B., Ha, E., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah, A., Marra, M., McGhee, J., Newbury, R., Pouzyrev, R., Riddle, D.L., Sonnhammer, E., Tian, H., Tu, D., Tyson, J.R., Vatcher, G., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quantit. Biol. 68: 159-69. Abstract Richmond, J.E. and Jorgensen, E.M. 1999. One GABA and two acetylcholine receptors function at the C. elegans neuromuscular junction. Nature Neurosci. 2: 791-797. Abstract Schafer, W.R. 2002. Genetic analysis of nicotinic signaling in worms and flies. J. Neurobiol. 53: 535-541. Abstract Stretton, A.O. 1976. Anatomy and development of the somatic musculature of the nematode Ascaris. J. Exp. Biol. 64: 773-788. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode, Caenorhabditis elegans. Dev. Biol. 56: 110–156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Waterston, R.H. 1988. Muscle. In "The nematode C. elegans" (W. B. Wood ed.) pp281-335. Cold Spring Harbor Laboratory Press, New York. Abstract White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 314B: 1-340. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Muscle system, introduction. In WormAtlas. doi:10.3908/wormatlas.1.6 Edited for the web by Laura A. Herndon. Last revision: May 2, 2012.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |